@@ -40,9 +40,13 @@
 #import <GNUstepBase/GSVersionMacros.h>
 
 #import <AppKit/NSResponder.h>
+#import <AppKit/NSUserInterfaceValidation.h>
+
+#if defined(__cplusplus)
+extern "C" {
+#endif
 
 @class NSArray;
-@class NSAutoreleasePool;
 @class NSDate;
 @class NSError;
 @class NSException;
@@ -81,11 +85,12 @@ enum {
 * NSTerminateLater.
 * </example>
 */
-typedef enum {
+enum {
   NSTerminateCancel = NO,
   NSTerminateNow = YES, 
   NSTerminateLater
-} NSApplicationTerminateReply;
+};
+typedef NSUInteger NSApplicationTerminateReply;
 
 /** 
 * Type used by -requestUserAttention: when an applications opened.  Possible values are:
@@ -94,35 +99,60 @@ typedef enum {
 * NSInformationalRequest;
 * </example>
 */
-typedef enum {
-  NSCriticalRequest,
-  NSInformationalRequest
-} NSRequestUserAttentionType;
+enum {
+  NSCriticalRequest = 0,
+  NSInformationalRequest = 10
+};
+typedef NSUInteger NSRequestUserAttentionType;
 
-#define NSAppKitVersionNumber10_0 0
+#define NSAppKitVersionNumber10_0   577
+#define NSAppKitVersionNumber10_1   620
+#define NSAppKitVersionNumber10_2   663
+#define NSAppKitVersionNumber10_2_3 663.6
+#define NSAppKitVersionNumber10_3   743
+#define NSAppKitVersionNumber10_3_2 743.14
+#define NSAppKitVersionNumber10_3_3 743.2
+#define NSAppKitVersionNumber10_3_5 743.24
+#define NSAppKitVersionNumber10_3_7 743.33
+#define NSAppKitVersionNumber10_3_9 743.36
+#define NSAppKitVersionNumber10_4   824
+#define NSAppKitVersionNumber10_4_1 824.1
+#define NSAppKitVersionNumber10_4_3 824.23
+#define NSAppKitVersionNumber10_4_4 824.33
+#define NSAppKitVersionNumber10_4_7 824.41
+#define NSAppKitVersionNumber10_5   949
+#define NSAppKitVersionNumber10_5_2 949.27
+#define NSAppKitVersionNumber10_5_3 949.33
+#define NSAppKitVersionNumber10_6   1038
+#define NSAppKitVersionNumber10_7   1138
+#define NSAppKitVersionNumber10_7_2 1138.23
+
+APPKIT_EXPORT const double NSAppKitVersionNumber;
 #endif
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
-typedef enum _NSApplicationDelegateReply
+enum _NSApplicationDelegateReply
 {
-  NSApplicationDelegateReplySuccess =0,
-  NSApplicationDelegateReplyCancel  =1,
-  NSApplicationDelegateReplyFailure =2
-} NSApplicationDelegateReply;
+  NSApplicationDelegateReplySuccess = 0,
+  NSApplicationDelegateReplyCancel  = 1,
+  NSApplicationDelegateReplyFailure = 2
+};
+typedef NSUInteger NSApplicationDelegateReply;
 
-typedef enum _NSApplicationPrintReply
+enum _NSApplicationPrintReply
 {
   NSPrintingCancelled = NO,
   NSPrintingSuccess = YES,
   NSPrintingFailure,
   NSPrintingReplyLater
-} NSApplicationPrintReply;
+};
+typedef NSUInteger NSApplicationPrintReply;
 #endif
 
 APPKIT_EXPORT NSString	*NSModalPanelRunLoopMode;
 APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
 
-@interface NSApplication : NSResponder <NSCoding>
+@interface NSApplication : NSResponder <NSCoding,NSUserInterfaceValidations>
 {
   NSGraphicsContext	*_default_context;
   NSEvent		*_current_event;
@@ -145,13 +175,14 @@ APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
   NSMutableArray	*_hidden;
   NSMutableArray	*_inactive;
   NSWindow		*_hidden_key;
+  NSWindow              *_hidden_main;
   GSInfoPanel           *_infoPanel;
 
   /* This autorelease pool should only be created and used by -run, with
      a single exception (which is why it is stored here as an ivar): the
      -terminate: method will destroy this autorelease pool before exiting
      the program.  */
-  NSAutoreleasePool     *_runLoopPool;
+  id             _runLoopPool;
 }
 
 /*
@@ -197,17 +228,17 @@ APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
 - (void) endModalSession: (NSModalSession)theSession;
 - (BOOL) isRunning;
 - (void) run;
-- (int) runModalForWindow: (NSWindow*)theWindow;
-- (int) runModalSession: (NSModalSession)theSession;
+- (NSInteger) runModalForWindow: (NSWindow*)theWindow;
+- (NSInteger) runModalSession: (NSModalSession)theSession;
 - (NSWindow *) modalWindow;
 - (void) sendEvent: (NSEvent*)theEvent;
 - (void) stop: (id)sender;
 - (void) stopModal;
-- (void) stopModalWithCode: (int)returnCode;
+- (void) stopModalWithCode: (NSInteger)returnCode;
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
-- (int) runModalForWindow: (NSWindow *)theWindow
-	relativeToWindow: (NSWindow *)docWindow;
+- (NSInteger) runModalForWindow: (NSWindow *)theWindow
+               relativeToWindow: (NSWindow *)docWindow;
 - (void) beginSheet: (NSWindow *)sheet
      modalForWindow: (NSWindow *)docWindow
       modalDelegate: (id)modalDelegate
@@ -215,16 +246,16 @@ APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
 	contextInfo: (void *)contextInfo;
 - (void) endSheet: (NSWindow *)sheet;
 - (void) endSheet: (NSWindow *)sheet
-       returnCode: (int)returnCode;
+       returnCode: (NSInteger)returnCode;
 #endif
 
 /*
  * Getting, removing, and posting events
  */
 - (NSEvent*) currentEvent;
-- (void) discardEventsMatchingMask: (unsigned int)mask
+- (void) discardEventsMatchingMask: (NSUInteger)mask
 		       beforeEvent: (NSEvent*)lastEvent;
-- (NSEvent*) nextEventMatchingMask: (unsigned int)mask
+- (NSEvent*) nextEventMatchingMask: (NSUInteger)mask
 			 untilDate: (NSDate*)expiration
 			    inMode: (NSString*)mode
 			   dequeue: (BOOL)flag;
@@ -271,7 +302,7 @@ APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
 - (void) setWindowsNeedUpdate: (BOOL)flag;
 - (void) updateWindows;
 - (NSArray*) windows;
-- (NSWindow*) windowWithWindowNumber: (int)windowNum;
+- (NSWindow*) windowWithWindowNumber: (NSInteger)windowNum;
 
 /*
  * Showing Standard Panels
@@ -363,8 +394,8 @@ APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
 /*
  * Methods for user attention requests
  */
-- (void) cancelUserAttentionRequest: (int)request;
-- (int) requestUserAttention: (NSRequestUserAttentionType)requestType;
+- (void) cancelUserAttentionRequest: (NSInteger)request;
+- (NSInteger) requestUserAttention: (NSRequestUserAttentionType)requestType;
 #endif
 
 @end
@@ -434,7 +465,6 @@ APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 /**
  * Sender requests application to open filenames.
- * <em>Not sent yet under GNUstep.</em>
  */
 - (void) application: (NSApplication*)app openFiles: (NSArray*)filenames;
 #endif
@@ -595,8 +625,8 @@ APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
 
 /**
  * Method used on OS X to allow an application to override the standard menu
- * obtained by right-clicking on the application's dock icon.  <em>Not sent
- * yet in GNUstep.</em>
+ * obtained by right-clicking on the application's dock icon.  <em>Called
+ * when the application uses Macintosh or Windows95 style menus.</em>
  */
 - (NSMenu *) applicationDockMenu: (NSApplication*)sender;
 
@@ -684,4 +714,8 @@ NSShowSystemInfoPanel(NSDictionary *options);
  */
 APPKIT_EXPORT NSApplication	*NSApp;
 
+#if defined(__cplusplus)
+}
+#endif
+
 #endif // _GNUstep_H_NSApplication
