@@ -3,7 +3,7 @@
 
    The window class
 
-   Copyright (C) 1996,1999 Free Software Foundation, Inc.
+   Copyright (C) 1996,1999,2004 Free Software Foundation, Inc.
 
    Author:  Scott Christley <scottc@net-community.com>
    Date: 1996
@@ -11,6 +11,8 @@
    Date: June 1998
    Modified:  Richard Frith-Macdonald <richard@brainstorm.co.uk>
    Date:  1998,1999
+   Author:  Quentin Mathe <qmathe@club-internet.fr>
+   Date: January 2004
 
    This file is part of the GNUstep GUI Library.
 
@@ -33,9 +35,10 @@
 
 #ifndef _GNUstep_H_NSWindow
 #define _GNUstep_H_NSWindow
+#import <GNUstepBase/GSVersionMacros.h>
 
-#include <AppKit/NSGraphicsContext.h>
-#include <AppKit/NSResponder.h>
+#import <AppKit/NSGraphicsContext.h>
+#import <AppKit/NSResponder.h>
 
 @class NSArray;
 @class NSData;
@@ -101,21 +104,23 @@ enum {
   NSMiniWindowMask = 128	/* GNUstep extension - miniwindows	*/
 };
 
-typedef enum _NSSelectionDirection {
+enum _NSSelectionDirection {
   NSDirectSelection,
   NSSelectingNext,
   NSSelectingPrevious
-} NSSelectionDirection;
+};
+typedef NSUInteger NSSelectionDirection;
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
-typedef enum _NSWindowButton
+enum _NSWindowButton
 {
   NSWindowCloseButton = 0,
   NSWindowMiniaturizeButton,
   NSWindowZoomButton,
   NSWindowToolbarButton,
   NSWindowDocumentIconButton
-} NSWindowButton;
+};
+typedef NSUInteger NSWindowButton;
 #endif 
 
 APPKIT_EXPORT NSSize NSIconSize;
@@ -168,13 +173,17 @@ APPKIT_EXPORT NSSize NSTokenSize;
   id            _firstResponder;
   id            _futureFirstResponder;
   NSView        *_initialFirstResponder;
+PACKAGE_SCOPE
   id            _delegate;
+@protected
   id            _fieldEditor;
-  id            _lastView;
+  id            _lastLeftMouseDownView;
+  id            _lastRightMouseDownView;
+  id            _lastOtherMouseDownView;
   id            _lastDragView;
-  int           _lastDragOperationMask;
-  int           _windowNum;
-  int           _gstate;
+  NSInteger     _lastDragOperationMask;
+  NSInteger     _windowNum;
+  NSInteger     _gstate;
   id            _defaultButtonCell;
   NSGraphicsContext *_context;
 
@@ -184,24 +193,30 @@ APPKIT_EXPORT NSSize NSTokenSize;
   NSString      *_miniaturizedTitle;
   NSImage       *_miniaturizedImage;
   NSString      *_windowTitle;
+PACKAGE_SCOPE
   NSPoint       _lastPoint;
+@protected
   NSBackingStoreType _backingType;
-  unsigned      _styleMask;
-  int           _windowLevel;
+  NSUInteger    _styleMask;
+  NSInteger     _windowLevel;
+PACKAGE_SCOPE
   NSRect        _rectNeedingFlush;
   NSMutableArray *_rectsBeingDrawn;
+@protected
   unsigned	_disableFlushWindow;
   
   NSWindowDepth _depthLimit;
   NSWindowController *_windowController;
-  int	        _counterpart;
-  float         _alphaValue;
+  NSInteger     _counterpart;
+  CGFloat       _alphaValue;
   
   NSMutableArray *_children;
   NSWindow       *_parent;
   NSCachedImageRep *_cachedImage;
   NSPoint        _cachedImageOrigin;
+  NSWindow       *_attachedSheet;
 
+PACKAGE_SCOPE
   struct GSWindowFlagsType {
     unsigned	accepts_drag:1;
     unsigned	is_one_shot:1;
@@ -243,8 +258,8 @@ APPKIT_EXPORT NSSize NSTokenSize;
     unsigned ignores_mouse_events: 1;
     unsigned preserves_content_during_live_resize: 1;
   } _f;
- 
-  void          *_reserved_s;
+@protected 
+  NSToolbar     *_toolbar;
   void          *_reserved_1;
 }
 
@@ -263,7 +278,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
  * Both rectangles are expressed in screen coordinates.
  */
 + (NSRect) contentRectForFrameRect: (NSRect)aRect
-			 styleMask: (unsigned int)aStyle;
+			 styleMask: (NSUInteger)aStyle;
 
 /**
  * Returns the rectangle which would be used for the on-screen frame of
@@ -272,15 +287,15 @@ APPKIT_EXPORT NSSize NSTokenSize;
  * Both rectangles are expressed in screen coordinates.
  */
 + (NSRect) frameRectForContentRect: (NSRect)aRect
-			 styleMask: (unsigned int)aStyle;
+			 styleMask: (NSUInteger)aStyle;
 
 /**
  * Returns the smallest frame width that will fit the given title
  * and style.  This is the on-screen width of the window including
  * decorations.
  */
-+ (float) minFrameWidthWithTitle: (NSString *)aTitle
-		       styleMask: (unsigned int)aStyle;
++ (CGFloat) minFrameWidthWithTitle: (NSString *)aTitle
+                         styleMask: (NSUInteger)aStyle;
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 - (NSRect) contentRectForFrameRect: (NSRect)frameRect;
@@ -290,7 +305,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
  * Initializing and getting a new NSWindow object
  */
 - (id) initWithContentRect: (NSRect)contentRect
-		 styleMask: (unsigned int)aStyle
+		 styleMask: (NSUInteger)aStyle
 		   backing: (NSBackingStoreType)bufferingType
 		     defer: (BOOL)flag;
 
@@ -301,7 +316,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
  * the window style mask.
  */
 - (id) initWithContentRect: (NSRect)contentRect
-		 styleMask: (unsigned int)aStyle
+		 styleMask: (NSUInteger)aStyle
 		   backing: (NSBackingStoreType)bufferingType
 		     defer: (BOOL)flag
 		    screen: (NSScreen*)aScreen;
@@ -367,7 +382,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
 - (NSPoint) cascadeTopLeftFromPoint: (NSPoint)topLeftPoint;
 
 - (void) center;
-- (int) resizeFlags;
+- (NSInteger) resizeFlags;
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) setFrame: (NSRect)frameRect
 	  display: (BOOL)displayFlag
@@ -375,6 +390,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
 - (NSTimeInterval) animationResizeTime: (NSRect)newFrame;
 - (void) performZoom: (id)sender;
 - (void) zoom: (id)sender;
+- (BOOL) isZoomed;
 - (BOOL) showsResizeIndicator;
 - (void) setShowsResizeIndicator: (BOOL)show;
 #endif
@@ -432,10 +448,10 @@ APPKIT_EXPORT NSSize NSTokenSize;
 - (void) orderFrontRegardless;
 - (void) orderOut: (id)sender;
 - (void) orderWindow: (NSWindowOrderingMode)place
-	  relativeTo: (int)otherWin;
+	  relativeTo: (NSInteger)otherWin;
 - (BOOL) isVisible;
-- (int) level;
-- (void) setLevel: (int)newLevel;
+- (NSInteger) level;
+- (void) setLevel: (NSInteger)newLevel;
 
 - (void) becomeKeyWindow;
 - (void) becomeMainWindow;
@@ -483,8 +499,8 @@ APPKIT_EXPORT NSSize NSTokenSize;
 /*
  * Window device attributes
  */
-- (int) windowNumber;
-- (int) gState;
+- (NSInteger) windowNumber;
+- (NSInteger) gState;
 - (NSDictionary*) deviceDescription;
 - (NSBackingStoreType) backingType;
 - (void) setBackingType: (NSBackingStoreType)type;
@@ -492,7 +508,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
 - (void) setOneShot: (BOOL)flag;
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
 - (NSGraphicsContext*) graphicsContext;
-- (float) userSpaceScaleFactor;
+- (CGFloat) userSpaceScaleFactor;
 #endif
 
 
@@ -533,12 +549,12 @@ APPKIT_EXPORT NSSize NSTokenSize;
  * Aiding event handling
  */
 - (NSEvent*) currentEvent;
-- (NSEvent*) nextEventMatchingMask: (unsigned int)mask;
-- (NSEvent*) nextEventMatchingMask: (unsigned int)mask
+- (NSEvent*) nextEventMatchingMask: (NSUInteger)mask;
+- (NSEvent*) nextEventMatchingMask: (NSUInteger)mask
 			 untilDate: (NSDate*)expiration
 			    inMode: (NSString*)mode
 			   dequeue: (BOOL)deqFlag;
-- (void) discardEventsMatchingMask: (unsigned int)mask
+- (void) discardEventsMatchingMask: (NSUInteger)mask
 		       beforeEvent: (NSEvent*)lastEvent;
 - (void) postEvent: (NSEvent*)event
 	   atStart: (BOOL)flag;
@@ -659,12 +675,12 @@ APPKIT_EXPORT NSSize NSTokenSize;
 - (void) setContentView: (NSView*)aView;
 - (void) setBackgroundColor: (NSColor*)color;
 - (NSColor*) backgroundColor;
-- (unsigned int) styleMask;
+- (NSUInteger) styleMask;
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) setHasShadow: (BOOL)hasShadow;
 - (BOOL) hasShadow;
-- (void) setAlphaValue: (float)windowAlpha;
-- (float) alphaValue;
+- (void) setAlphaValue: (CGFloat)windowAlpha;
+- (CGFloat) alphaValue;
 - (void) setOpaque: (BOOL)isOpaque;
 - (BOOL) isOpaque;
 #endif
@@ -712,7 +728,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
  */
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
 + (NSButton *) standardWindowButton: (NSWindowButton)button 
-                       forStyleMask: (unsigned int) mask;
+                       forStyleMask: (NSUInteger) mask;
 - (NSButton *) standardWindowButton: (NSWindowButton)button;
 #endif
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
@@ -746,6 +762,15 @@ APPKIT_EXPORT NSSize NSTokenSize;
 
 @end
 
+@class NSToolbar;
+
+@interface NSWindow (Toolbar)
+- (void) runToolbarCustomizationPalette: (id)sender;
+- (void) toggleToolbarShown: (id)sender;
+- (NSToolbar *) toolbar;
+- (void) setToolbar: (NSToolbar*)toolbar;
+@end
+
 #if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 /*
  * GNUstep backend methods
