@@ -29,32 +29,37 @@
 #ifndef _GSDisplayServer_h_INCLUDE
 #define _GSDisplayServer_h_INCLUDE
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSGeometry.h>
-#include <Foundation/NSMapTable.h>
-#include <Foundation/NSSet.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSGeometry.h>
 
-#include <AppKit/NSDragging.h>
-#include <AppKit/AppKitDefines.h>
-#include <AppKit/NSGraphicsContext.h>
+#import <AppKit/AppKitDefines.h>
+#import <AppKit/NSDragging.h>
+#import <AppKit/NSGraphicsContext.h>
 
 @class NSArray;
-@class NSMutableDictionary;
-@class NSEvent;
-@class NSImage;
+@class NSCountedSet;
+@class NSDictionary;
+@class NSMapTable;
 @class NSMutableArray;
 @class NSMutableData;
+@class NSMutableDictionary;
+@class NSString;
+
+@class NSEvent;
+@class NSImage;
+
 @class GSDisplayServer;
 @class NSGraphicsContext;
+@class NSWindow;
 
-#ifndef	NO_GNUSTEP
-APPKIT_EXPORT GSDisplayServer * GSServerForWindow(NSWindow *window);
-APPKIT_EXPORT GSDisplayServer * GSCurrentServer(void);
+#if !NO_GNUSTEP
+APPKIT_EXPORT GSDisplayServer *GSServerForWindow(NSWindow *window);
+APPKIT_EXPORT GSDisplayServer *GSCurrentServer(void);
 
 /* Display attributes */
-APPKIT_EXPORT NSString * GSDisplayName;
-APPKIT_EXPORT NSString * GSDisplayNumber;
-APPKIT_EXPORT NSString * GSScreenNumber;
+APPKIT_EXPORT NSString *GSDisplayName;
+APPKIT_EXPORT NSString *GSDisplayNumber;
+APPKIT_EXPORT NSString *GSScreenNumber;
 
 @interface GSDisplayServer : NSObject
 {
@@ -108,6 +113,9 @@ APPKIT_EXPORT NSString * GSScreenNumber;
 - (NSImage *) iconTileImage;
 - (NSSize) iconSize;
 
+/* Screen capture */ 
+- (NSImage *) contentsOfScreen: (int)screen inRect: (NSRect)rect;
+
 @end
 
 /* ----------------------------------------------------------------------- */
@@ -149,19 +157,24 @@ APPKIT_EXPORT NSString * GSScreenNumber;
 - (void) docedited: (int) edited : (int)win;
 - (void) setinputstate: (int)state : (int)win;
 - (void) setinputfocus: (int)win;
-- (void) setalpha: (float)alpha: (int)win;
+- (void) setalpha: (float)alpha : (int)win;
 - (void) setShadow: (BOOL)hasShadow : (int)win;
 
 - (NSPoint) mouselocation;
 - (NSPoint) mouseLocationOnScreen: (int)aScreen window: (int *)win;
 - (BOOL) capturemouse: (int)win;
 - (void) releasemouse;
+- (void) setMouseLocation: (NSPoint)mouseLocation onScreen: (int)aScreen;
 - (void) hidecursor;
 - (void) showcursor;
 - (void) standardcursor: (int) style : (void**)cid;
-- (void) imagecursor: (NSPoint)hotp : (int)w : (int)h : (int)colors
-		    : (const unsigned char *) image : (void**)cid;
+- (void) imagecursor: (NSPoint)hotp : (NSImage *) image : (void**)cid;
 - (void) setcursorcolor: (NSColor *)fg : (NSColor *)bg : (void*)cid;
+- (void) recolorcursor: (NSColor *)fg : (NSColor *)bg : (void*) cid;
+- (void) setcursor: (void*) cid;
+- (void) freecursor: (void*) cid;
+- (void) setParentWindow: (int)parentWin 
+          forChildWindow: (int)childWin;
 
 @end
 
